<?php
/**
 * This plugin utilizes Open Source code. Details of these open source projects along with their licenses can be found below.
 * We acknowledge and are grateful to these developers for their contributions to open source.
 *
 * Project: mobile-dj-manager https://github.com/deckbooks/mobile-dj-manager
 * License: (GNU General Public License v2.0) https://github.com/deckbooks/mobile-dj-manager/blob/master/license.txt
 *
 * @author: Mike Howard, Jack Mawhinney, Dan Porter
 *
 * Admin Actions
 *
 * @package     TMEM
 * @subpackage  Admin/Actions
 * @copyright   Copyright (c) 2016, Mike Howard
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.3
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Processes all TMEM actions sent via POST and GET by looking for the 'tmem-action'
 * request and running do_action() to call the function
 *
 * @since 1.0
 * @return void
 */
function tmem_process_actions() {
	if ( isset( $_POST['tmem-action'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification

		if ( isset( $_FILES ) ) {
			$_POST['FILES'] = $_FILES;
		}

		do_action( 'tmem-' . sanitize_text_field( wp_unslash( $_POST['tmem-action'] ) ), $_POST ); // phpcs:ignore WordPress.Security.NonceVerification

	}

	if ( isset( $_GET['tmem-action'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification

		if ( isset( $_FILES ) ) {
			$_POST['FILES'] = $_FILES;
		}

		do_action( 'tmem-' . sanitize_text_field( wp_unslash( $_GET['tmem-action'] ) ), $_GET ); // phpcs:ignore WordPress.Security.NonceVerification

	}

}
add_action( 'admin_init', 'tmem_process_actions' );

/**
 * Admin action field.
 *
 * Prints the output for a hidden form field which is required for admin post forms.
 *
 * @since   1.3
 * @param   str  $action     The action identifier.
 * @param   bool $echo       True echo's the input field, false to return as a string.
 * @return  str     $input      Hidden form field string
 */
function tmem_admin_action_field( $action, $echo = true ) {
	$name = apply_filters( 'tmem-action_field_name', 'tmem-action' );

	$input = '<input type="hidden" name="' . $name . '" id="' . $name . '" value="' . $action . '" />';

	if ( ! empty( $echo ) ) {
		echo apply_filters( 'tmem-action_field', $input, $action ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	} else {
		return apply_filters( 'tmem-action_field', $input, $action );
	}

} // tmem_admin_action_field
