<?php
/**
 * The Contract pages helper.
 *
 * @package     TMEM
 * @subpackage  Admin\Contract
 * @copyright   Copyright (c) 2016, Mike Howard
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @author      TMEM
 * @since       1.5.9
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
	/**
	 * Contract View
	 */
class Contract_View {
	/**
	 * Contract View
	 *
	 * @var str $slug Contract view.
	 */
	protected $slug = 'tmem-view-contract';

	/**
	 * The Constructor.
	 */
	public function __construct() {
		\add_action( 'admin_menu', array( $this, 'add_admin_menu' ) );

		// If the page is not this page stop here.
		if ( ! $this->is_current_page() ) {
			return;
		}

		\add_action( 'admin_init', array( $this, 'admin_page' ), 30 );
	}

	/**
	 * Add the admin menu item.
	 */
	public function add_admin_menu() {
		if ( $this->get( 'page' ) !== $this->slug ) {
			return;
		}

		add_submenu_page(
			null,
			esc_html__( 'Contract View', 'mobile-dj-manager' ),
			esc_html__( 'Contract View', 'mobile-dj-manager' ),
			'tmem_employee',
			$this->slug,
			array( $this, 'admin_page' )
		);
	}

	/**
	 * Output the admin page.
	 */
	public function admin_page() {

		// Do not proceed if we're not on the right page.
		if ( $this->get( 'page' ) !== $this->slug ) {
			return;
		}

		if ( ob_get_length() ) {
			ob_end_clean();
		}

		if ( ! tmem_employee_can( 'manage_events' ) ) {
			return;
		}

		$event_id = isset( $_GET['event_id'] ) ? absint( wp_unslash( $_GET['event_id'] ) ) : 0; // phpcs:ignore WordPress.Security.NonceVerification.Recommended

		if ( empty( $event_id ) ) {
			esc_html_e( 'The event cannot be found', 'mobile-dj-manager' );
			exit;
		}

		$tmem_event = new TMEM_Event( $event_id );

		if ( ! tmem_is_admin() ) {
			if ( ! array_key_exists( get_current_user_id(), $tmem_event->get_all_employees() ) ) {
				return;
			}
		}

		if ( ! $tmem_event->get_contract_status() ) {
			/* translators: % event style */
			printf( esc_html__( 'The contract for this %s is not signed', 'mobile-dj-manager' ), esc_html( tmem_get_label_singular() ) );
			exit;
		}

		$contract_id = $tmem_event->get_contract();

		if ( empty( $contract_id ) ) {
			return;
		}

		echo tmem_show_contract( $contract_id, $tmem_event ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

		exit;
	}

	/**
	 * Is the page is current page.
	 *
	 * @return boolean
	 */
	public function is_current_page() {
		$page = isset( $_GET['page'] ) && ! empty( $_GET['page'] ) ? filter_input( INPUT_GET, 'page' ) : false; // phpcs:ignore WordPress.Security.NonceVerification.Recommended
		return $page === $this->slug;
	}

	/**
	 * Get field from query string.
	 *
	 * @param str $id ID.
	 * @param str $default Default.
	 * @param str $filter Filter.
	 * @param str $flag Flag.
	 */
	public static function get( $id, $default = false, $filter = FILTER_DEFAULT, $flag = array() ) {
		return filter_has_var( INPUT_GET, $id ) ? filter_input( INPUT_GET, $id, $filter, $flag ) : $default;
	}

}
new Contract_View();
