<?php
/**
 * This plugin utilizes Open Source code. Details of these open source projects along with their licenses can be found below.
 * We acknowledge and are grateful to these developers for their contributions to open source.
 *
 * Project: mobile-dj-manager https://github.com/deckbooks/mobile-dj-manager
 * License: (GNU General Public License v2.0) https://github.com/deckbooks/mobile-dj-manager/blob/master/license.txt
 *
 * @author: Mike Howard, Jack Mawhinney, Dan Porter
 *
 * Earnings Export Class
 *
 * This class handles earnings export
 *
 * @package     TMEM
 * @subpackage  Admin/Reports
 * @copyright   Copyright (c) 2016, Mike Howard
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0.4
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * TMEM_Earnings_Export Class
 *
 * @since   1.0.4
 */
class TMEM_Earnings_Export extends TMEM_Export {

	/**
	 * Our export type. Used for export-type specific filters/actions
	 *
	 * @var     str
	 * @since   1.0.4
	 */
	public $export_type = 'earnings';

	/**
	 * Set the export headers
	 *
	 * @access  public
	 * @since   1.0.4
	 * @return  void
	 */
	public function headers() {

		ignore_user_abort( true );

		tmem_set_time_limit( 0 );

		nocache_headers();
		header( 'Content-Type: text/csv; charset=utf-8' );
		header( 'Content-Disposition: attachment; filename=' . apply_filters( 'tmem_earnings_export_filename', 'tmem-export-' . $this->export_type . '-' . date( 'n' ) . '-' . date( 'Y' ) ) . '.csv' );
		header( 'Expires: 0' );

	} // headers

	/**
	 * Set the CSV columns
	 *
	 * @access  public
	 * @since   1.0.4
	 * @return  srr     $cols   All the columns
	 */
	public function csv_cols() {

		$cols = array(
			'date'     => __( 'Date', 'mobile-events-manager' ),
			// 'events'   => tmem_get_label_plural(),
			'earnings' => __( 'Earnings', 'mobile-events-manager' ) . ' (' . html_entity_decode( tmem_currency_filter( '' ) ) . ')',
		);

		return $cols;

	} // csv_cols

	/**
	 * Get the Export Data
	 *
	 * @access  public
	 * @since   1.0.4
	 * @return  arr     $data   The data for the CSV file
	 */
	public function get_data() {

		$start_year  = isset( $_POST['start_year'] ) ? absint( $_POST['start_year'] ) : date( 'Y' );
		$end_year    = isset( $_POST['end_year'] ) ? absint( $_POST['end_year'] ) : date( 'Y' );
		$start_month = isset( $_POST['start_month'] ) ? absint( $_POST['start_month'] ) : date( 'n' );
		$end_month   = isset( $_POST['end_month'] ) ? absint( $_POST['end_month'] ) : date( 'n' );

		$data  = array();
		$year  = $start_year;
		$stats = new TMEM_Stats();

		while ( $year <= $end_year ) {

			if ( $year == $start_year && $year == $end_year ) {

				$m1 = $start_month;
				$m2 = $end_month;

			} elseif ( $year == $start_year ) {

				$m1 = $start_month;
				$m2 = 12;

			} elseif ( $year == $end_year ) {

				$m1 = 1;
				$m2 = $end_month;

			} else {

				$m1 = 1;
				$m2 = 12;

			}

			while ( $m1 <= $m2 ) {

				$date1 = mktime( 0, 0, 0, $m1, 1, $year );
				$date2 = mktime( 0, 0, 0, $m1, cal_days_in_month( CAL_GREGORIAN, $m1, $year ), $year );

				$event_status = array_keys( tmem_all_event_status() );

				$data[] = array(
					'date'     => date_i18n( 'F Y', $date1 ),
					// 'events'   => $stats->get_events_by_date( null, $m1, $year ),
					'earnings' => tmem_format_amount( $stats->get_earnings( $m1, $year ) ),
				);

				$m1++;

			}

			$year++;

		}

		$data = apply_filters( 'tmem_export_get_data', $data );
		$data = apply_filters( 'tmem_export_get_data_' . $this->export_type, $data );

		return $data;

	} // get_data

} // TMEM_Earnings_Export
