<?php
/**
 * This plugin utilizes Open Source code. Details of these open source projects along with their licenses can be found below.
 * We acknowledge and are grateful to these developers for their contributions to open source.
 *
 * Project: mobile-dj-manager https://github.com/deckbooks/mobile-dj-manager
 * License: (GNU General Public License v2.0) https://github.com/deckbooks/mobile-dj-manager/blob/master/license.txt
 *
 * @author: Mike Howard, Jack Mawhinney, Dan Porter
 *
 * Exports Actions
 *
 * These are actions related to exporting data from Mobile Events Manager.
 *
 * @package     TMEM
 * @subpackage  Admin/Export
 * @copyright   Copyright (c) 2016, Mike Howard
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Process the download file generated by a batch export
 *
 * @since   1.0.4
 * @return  void
 */
function tmem_process_batch_export_download() {

	if ( ! isset( $_REQUEST['nonce'] ) || ! wp_verify_nonce( $_REQUEST['nonce'], 'tmem-batch-export' ) ) {
		wp_die( esc_html__( 'Nonce verification failed', 'mobile-events-manager' ), esc_html__( 'Error', 'mobile-events-manager' ), array( 'response' => 403 ) );
	}

	require_once TMEM_PLUGIN_DIR . '/includes/admin/reporting/export/class-batch-export.php';

	do_action( 'tmem_batch_export_class_include', sanitize_text_field( wp_unslash( $_REQUEST['class'] ) ) ); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotValidated

	$export = new $_REQUEST['class'](); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized, WordPress.Security.ValidatedSanitizedInput.InputNotValidated, WordPress.Security.ValidatedSanitizedInput.MissingUnslash
	$export->export();

}
add_action( 'tmem_download_batch_export', 'tmem_process_batch_export_download' );

/**
 * Export all the clients to a CSV file.
 *
 * Note: The WordPress Database API is being used directly for performance
 * reasons (workaround of calling all posts and fetch data respectively)
 *
 * @since   1.0.4
 * @return  void
 */
function tmem_export_all_clients() {
	require_once TMEM_PLUGIN_DIR . '/includes/admin/reporting/class-tmem-clients-export.php';

	$client_export = new TMEM_Clients_Export();

	$client_export->export();
} // tmem_export_all_clients
add_action( 'tmem_email_export', 'tmem_export_all_clients' );

/**
 * Add a hook allowing extensions to register a hook on the batch export process
 *
 * @since   1.0.4
 * @return  void
 */
function tmem_register_batch_exporters() {
	if ( is_admin() ) {
		do_action( 'tmem_register_batch_exporter' );
	}
} // tmem_register_batch_exporters
add_action( 'plugins_loaded', 'tmem_register_batch_exporters' );

/**
 * Register the events batch exporter
 *
 * @since   1.0.4
 */
function tmem_register_events_batch_export() {
	add_action( 'tmem_batch_export_class_include', 'tmem_include_events_batch_processer', 10, 1 );
} // tmem_register_txns_batch_export
add_action( 'tmem_register_batch_exporter', 'tmem_register_events_batch_export', 10 );

/**
 * Loads the events batch process if needed
 *
 * @since   1.0.4
 * @param   str $class  The class being requested to run for the batch export
 * @return  void
 */
function tmem_include_events_batch_processer( $class ) {

	if ( 'TMEM_Batch_Export_Events' === $class ) {
		require_once TMEM_PLUGIN_DIR . '/includes/admin/reporting/export/class-batch-export-events.php';
	}

} // tmem_include_txns_batch_processer

/**
 * Register the transactions batch exporter
 *
 * @since   1.0.4
 */
function tmem_register_txns_batch_export() {
	add_action( 'tmem_batch_export_class_include', 'tmem_include_txns_batch_processer', 10, 1 );
} // tmem_register_txns_batch_export
add_action( 'tmem_register_batch_exporter', 'tmem_register_txns_batch_export', 10 );

/**
 * Loads the transactions batch process if needed
 *
 * @since   1.0.4
 * @param   str $class  The class being requested to run for the batch export
 * @return  void
 */
function tmem_include_txns_batch_processer( $class ) {

	if ( 'TMEM_Batch_Export_Txns' === $class ) {
		require_once TMEM_PLUGIN_DIR . '/includes/admin/reporting/export/class-batch-export-txns.php';
	}

} // tmem_include_txns_batch_processer

/**
 * Register the clients batch exporter
 *
 * @since   1.0.4
 */
function tmem_register_clients_batch_export() {
	add_action( 'tmem_batch_export_class_include', 'tmem_include_clients_batch_processer', 10, 1 );
} // tmem_register_clients_batch_export
add_action( 'tmem_register_batch_exporter', 'tmem_register_clients_batch_export', 10 );

/**
 * Loads the clients batch process if needed
 *
 * @since   1.0.4
 * @param   str $class  The class being requested to run for the batch export
 * @return  void
 */
function tmem_include_clients_batch_processer( $class ) {

	if ( 'TMEM_Batch_Export_Clients' === $class ) {
		require_once TMEM_PLUGIN_DIR . '/includes/admin/reporting/export/class-batch-export-clients.php';
	}

} // tmem_include_clients_batch_processer

/**
 * Register the employees batch exporter
 *
 * @since   1.0.4
 */
function tmem_register_employees_batch_export() {
	add_action( 'tmem_batch_export_class_include', 'tmem_include_employees_batch_processer', 10, 1 );
} // tmem_register_clients_batch_export
add_action( 'tmem_register_batch_exporter', 'tmem_register_employees_batch_export', 10 );

/**
 * Loads the employees batch process if needed
 *
 * @since   1.0.4
 * @param   str $class  The class being requested to run for the batch export
 * @return  void
 */
function tmem_include_employees_batch_processer( $class ) {

	if ( 'TMEM_Batch_Export_Employees' === $class ) {
		require_once TMEM_PLUGIN_DIR . '/includes/admin/reporting/export/class-batch-export-employees.php';
	}

} // tmem_include_employees_batch_processer
