<?php
/**
 * This plugin utilizes Open Source code. Details of these open source projects along with their licenses can be found below.
 * We acknowledge and are grateful to these developers for their contributions to open source.
 *
 * Project: mobile-dj-manager https://github.com/deckbooks/mobile-dj-manager
 * License: (GNU General Public License v2.0) https://github.com/deckbooks/mobile-dj-manager/blob/master/license.txt
 *
 * @author: Mike Howard, Jack Mawhinney, Dan Porter
 *
 * tmem-dashboard.php
 * TMEM_Dashboard Class
 * 21/02/2015
 *
 * @version 1.0
 * @21/02/2015
 *
 * TODO 7 day status (admin & DJ)
 *  Status overview for month (admin & DJ)
 *  To do list (admin only)
 *  Availability check
 *  Recent activity (payments etc..)
 *  Latest news
 */

class TMEM_Dashboard {

	/*
	 * The Contact Form constructor
	 *
	 *
	 */
	public function __construct() {

	} // __construct

	/*
	 * Retrieve all events listed by status for specified period
	 *
	 * @param       str     $status     The event status
	 *              str     $period     month or year (current)
	 *              bool    $str        all, dj, client
	 *
	 */
	public function all_events_by_status( $status = '', $period = '', $type = false, $user_id = '' ) {
		global $tmem;

		if ( empty( $status ) || empty( $period ) ) {
			if ( TMEM_DEBUG == true ) {
				TMEM()->debug->log_it(
					'ERROR: No ' . ( empty( $status ) ? 'status' : 'period' ) .
					' was provided in ' . __METHOD__,
					true
				);
			}

			return false;
		}

		if ( ! empty( $type ) && empty( $user_id ) ) {
			if ( TMEM_DEBUG == true ) {
				TMEM()->debug->log_it( 'ERROR: No user ID was provided in ' . __METHOD__, true );
			}

			return false;
		}

		$start_date = $period == 'year' ? date( 'Y-01-01' ) : date( 'Y-m-01' );
		$end_date   = $period == 'year' ? date( 'Y-12-31' ) : date( 'Y-m-t' );

		$args = array(
			'posts_per_page' => -1,
			'post_type'      => 'tmem-event',
			'post_status'    => $status,
			'meta_key'       => '_tmem_event_date',
			'orderby'        => 'meta_value',
			'order'          => 'DESC',
		);

		if ( ! empty( $type ) ) {
			$args['meta_query'] = array(
				'relation' => 'AND',
				array(
					'key'     => '_tmem_event_date',
					'value'   => array( $start_date, $end_date ),
					'type'    => 'date',
					'compare' => 'BETWEEN',
				),
				array(
					'key'     => '_tmem_event_' . $type,
					'value'   => $user_id,
					'compare' => '=',
				),
			);
		} else {
			$args['meta_query'] = array(
				'key'     => '_tmem_event_date',
				'value'   => array( $start_date, $end_date ),
				'type'    => 'date',
				'compare' => 'BETWEEN',
			);
		}

		$events = get_posts( $args );

		return $events;

	} // all_events_by_status

	/*
	 * Retrieve earnings by the given period
	 *
	 * @param   str     $period     Required: week, month or year
	 *          int     $user_id    Optional: ID of the DJ to check, otherwise check all
	 *          bool    $earned     true for already earned, false for possible
	 * @return
	 */
	public function period_earnings( $period = '', $user_id = '', $earned = '' ) {
		global $tmem;

		if ( empty( $period ) ) {
			if ( TMEM_DEBUG == true ) {
				TMEM()->debug->log_it( 'ERROR: No period was provided in ' . __METHOD__, true );
			}
		} elseif ( $period == 'week' ) {
			$start_date = date( 'Y-m-d', strtotime( '-7 day' ) );
			$end_date   = date( 'Y-m-d' );
		} elseif ( $period == 'month' ) {
			$start_date = date( 'Y-m-01' );
			$end_date   = date( 'Y-m-t' );
		} else {
			$start_date = date( 'Y-01-01' );
			$end_date   = date( 'Y-12-31' );
		}

		$user_id = ! empty( $user_id ) ? $user_id : '';

		$args                = array(
			'post_type'      => 'tmem-event',
			'posts_per_page' => -1,
			'meta_key'       => '_tmem_event_date',
			'orderby'        => 'meta_value',
			'order'          => 'DESC',
		);
		$args['post_status'] = empty( $earned ) ? array(
			'tmem-enquiry',
			'tmem-unattended',
			'tmem-contract',
			'tmem-approved',
			'tmem-completed',
		) : 'tmem-completed';

		if ( ! empty( $user_id ) ) {
			$args['meta_query'] = array(
				'relation' => 'AND',
				array(
					'key'     => '_tmem_event_date',
					'value'   => array( $start_date, $end_date ),
					'type'    => 'date',
					'compare' => 'BETWEEN',
				),
				array(
					'key'     => '_tmem_event_dj',
					'value'   => $user_id,
					'compare' => '=',
				),
			);
		} // End if( !empty( $user ) )
		else {
			$args['meta_query'] = array(
				'key'     => '_tmem_event_date',
				'value'   => array( $start_date, $end_date ),
				'type'    => 'date',
				'compare' => 'BETWEEN',
			);
		}
		$earnings = '0.00';
		$events   = get_posts( $args );
		foreach ( $events as $event ) {
			$event_cost = get_post_meta( $event->ID, '_tmem_event_cost', true );
			$earnings  += $event_cost;

			if ( ! empty( $earnings ) ) {
				$transactions = TMEM()->txns->get_event_transactions( $event->ID );
				foreach ( $transactions as $transaction ) {
					$status = get_post_meta( $transaction->ID, '_tmem_txn_status', true );
					if ( empty( $status ) || $status == 'Completed' ) {
						$txn_total = get_post_meta( $transaction->ID, '_tmem_txn_total', true );
					}

					if ( ! empty( $txn_total ) ) {
						if ( $transaction->post_status == 'tmem-income' ) {
							$earnings += $txn_total;
						} else {
							$earnings -= $txn_total;
						}
					}
				} // foreach( $transactions as $transaction )
			} // if( !empty( $earnings ) )

		} // End foreach( $events as $event )

		return tmem_currency_filter( tmem_sanitize_amount( $earnings ) );
	} // period_earnings

} // Class

	/* -- Insantiate the TMEM_Dashboard class -- */
	$tmem_dash = new TMEM_Dashboard();
