<?php
/**
 * This plugin utilizes Open Source code. Details of these open source projects along with their licenses can be found below.
 * We acknowledge and are grateful to these developers for their contributions to open source.
 *
 * Project: mobile-dj-manager https://github.com/deckbooks/mobile-dj-manager
 * License: (GNU General Public License v2.0) https://github.com/deckbooks/mobile-dj-manager/blob/master/license.txt
 *
 * @author: Mike Howard, Jack Mawhinney, Dan Porter
 */
	defined( 'ABSPATH' ) or die( 'Direct access to this page is disabled!!!' );

if ( ! tmem_employee_can( 'view_clients_list' ) ) {
	wp_die(
		'<h1>' . esc_html__( 'Cheatin&#8217; uh?', 'mobile-events-manager' ) . '</h1>' .
		'<p>' . esc_html__( 'You do not have permission to manage clients.', 'mobile-events-manager' ) . '</p>',
		403
	);
}

// This class extends WP_List_Table
if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

/**
 * Class Name: TMEM_Client_Manager
 * User management interface for employees
 */
if ( ! class_exists( 'TMEM_Client_Manager' ) ) :
	class TMEM_Client_Manager extends WP_List_Table {
		private static $orderby;
		private static $order;
		public static $clients;
		public static $total_clients;
		private static $display_role;

		/**
		 * Class constructor
		 */
		public function __construct() {
			parent::__construct(
				array(
					'singular' => 'tmem_list_client', // Singular label
					'plural'   => 'tmem_list_clients', // Plural label, also this will be one of the table css class
					'ajax'     => false, // We won't support Ajax for this table
				)
			);
			$this->process_bulk_actions();
			$this->get_clients();

			$this->prepare_items();

			// Display the page
			$this->client_page();
		} // __construct

		public function get_clients() {
			// Filter our search by role if we need to
			self::$display_role = ! empty( $_GET['display_role'] ) ? sanitize_text_field( wp_unslash( $_GET['display_role'] ) ) : array( 'client', 'inactive_client' );
			self::$orderby      = ! empty( $_GET['orderby'] ) ? sanitize_text_field( wp_unslash( $_GET['orderby'] ) ) : 'display_name';
			self::$order        = ! empty( $_GET['order'] ) ? sanitize_text_field( wp_unslash( $_GET['order'] ) ) : 'ASC';

			// Searching
			if ( ! empty( $_POST['s'] ) ) {

				// Build out the query args for the WP_User_Query
				self::$clients = get_users(
					array(
						'search'         => sanitize_text_field( wp_unslash( $_POST['s'] ) ),
						'search_columns' => array( 'ID', 'user_login', 'user_nicename', 'user_email', 'display_name' ),
						'role__in'       => array( 'client', 'inactive_client' ),
						'orderby'        => self::$orderby,
						'order'          => self::$order,
					)
				);

			} elseif ( ! empty( $_POST['filter_client'] ) ) {

				self::$clients = tmem_get_clients(
					self::$display_role,
					sanitize_text_field( wp_unslash( $_POST['filter_client'] ) ),
					self::$orderby,
					self::$order
				);

			} else {

				self::$clients = tmem_get_clients(
					self::$display_role,
					! tmem_employee_can( 'list_all_clients' ) ? get_current_user_id() : '',
					self::$orderby,
					self::$order
				);

			}

			self::$total_clients = count( self::$clients );

		} // get_clients

		/**
		 * Display the page header for the client management interface
		 */
		public function client_page() {
			?>
			<div class="wrap">
			<div id="icon-themes" class="icon32"></div>
			<h1><?php printf( esc_html__( '%s Clients', 'mobile-events-manager' ), esc_attr( tmem_get_option( 'company_name' ) ) ); ?></h1>
			<form name="tmem-client-list" id="tmem-client-list" method="post">
				<?php $this->views(); ?>
				<?php $this->search_box( __( 'Search', 'mobile-events-manager' ), 'search_id' ); ?>
				<?php $this->display(); ?>
			</form>
			<?php
		} // page_header

		/**
		 * Define items/data to be displayed before and after the list table
		 *
		 * @param   str $action     Required: top for top of the table or bottom
		 *
		 * @return  str                 The HTML to be output
		 */
		public function extra_tablenav( $which ) {
			if ( $which == 'top' ) {
				?>
			<div class="alignleft actions">
				<label class="screen-reader-text" for="filter_client"><?php esc_html_e( 'Only show', 'mobile-events-manager' ); ?>&hellip;</label>
				<?php
				tmem_employee_dropdown(
					array(
						'name'            => 'filter_client',
						'first_entry'     => __( 'Show clients of', 'mobile-events-manager' ) . '...',
						'first_entry_val' => '',
						'structure'       => true,
						'echo'            => true,
					)
				);
				?>
				<input type="submit" name="show_only" id="show_only" class="button" value="<?php esc_attr_e( 'Go!', 'mobile-events-manager' ); ?>" />
			</div>
				<?php
			}
		} // extra_tablenav

		/**
		 * Define the table column ID's and names
		 *
		 * @param
		 *
		 * @return  $arr    $columns    The table column IDs and names
		 */
		public function get_columns() {
			$columns = array(
				'cb'     => '<input type="checkbox" />',
				'name'   => __( 'Name', 'mobile-events-manager' ),
				'events' => __( 'Total Events', 'mobile-events-manager' ),
				'next'   => __( 'Next Event', 'mobile-events-manager' ),
				'login'  => __( 'Last Login', 'mobile-events-manager' ),
			);

			return $columns;
		} // get_columns

		function get_sortable_columns() {
			$sortable_columns = array(
				'name' => array( 'display_name', true ),
			);
			return $sortable_columns;
		}

		/**
		 * This is where we define the layout of the list table and the data to be used
		 *
		 * @param
		 *
		 * @return
		 */
		public function prepare_items() {
			// Prepare columns
			$columns               = $this->get_columns();
			$hidden                = array();
			$sortable              = $this->get_sortable_columns();
			$this->_column_headers = array( $columns, $hidden, $sortable );

			// Pagination. TODO
			$per_page     = $this->get_items_per_page( 'users_per_page' );
			$current_page = $this->get_pagenum();

			$total_items = self::$total_clients;

			$this->set_pagination_args(
				array(
					'total_items' => $total_items,
					'per_page'    => $per_page,
				)
			);

			$this->items = array_slice( self::$clients, ( ( $current_page - 1 ) * $per_page ), $per_page );
		} // prepare_items

		/**
		 * Specifies the default text to be displayed when there is no data
		 *
		 * @param
		 *
		 * @return  str     The text to be displayed when there are no results to display
		 */
		public function no_items() {
			esc_html_e( "No Client's found.", 'mobile-events-manager' );
		} // no_items

		/**
		 * Specifies the default data to be displayed within columns that do not have a
		 * defined method within this class
		 *
		 * @param   obj $item           The object array for the current data object
		 *      str     $column_name    The name of the current column
		 *
		 * @return  str     The data to be output into the column
		 */
		public function column_default( $item, $column_name ) {
			global $wp_roles;

			switch ( $column_name ) {
				default:
					return;
			}
		} // column_default

		/**
		 * Create the HTML output for the checkboxes column
		 *
		 * @param   obj $item   The object array for the current item
		 *
		 * @return  str     The HTML output for the checkbox column
		 */
		public function column_cb( $item ) {
			echo '<input type="checkbox" name="client[]" id="clients-' . esc_attr( $item->ID ) . '" value="' . esc_attr( $item->ID ) . '" />';
		} // column_cb

		/**
		 * Create the HTML output for the name column
		 *
		 * @param   obj $item   The object array for the current item
		 *
		 * @return  str     The HTML output for the name column
		 */
		public function column_name( $item ) {
			if ( current_user_can( 'edit_users' ) || $item->ID == get_current_user_id() ) {
				$edit_users = true;
			}

			if ( ! empty( $edit_users ) ) {
				echo '<a href="' . esc_url( get_edit_user_link( $item->ID ) ) . '">';
			}

			echo esc_html( $item->display_name );

			if ( ! empty( $edit_users ) ) {
				echo '</a>';
			}
		} // column_name

		/**
		 * Create the HTML output for the events column
		 *
		 * @param   obj $item   The object array for the current item
		 *
		 * @return  str     The HTML output for the events column
		 */
		public function column_events( $item ) {
			$total = tmem_get_client_events( $item->ID );

			echo ( ! empty( $total ) ?
				'<a href="' . esc_url(
					admin_url(
						'edit.php?s&post_type=tmem-event?s&post_status=all' .
						'&post_type=tmem-event&action=-1&tmem_filter_date=0&tmem_filter_type&tmem_filter_employee=0' .
						'&tmem_filter_client=' . $item->ID . '&filter_action=Filter&paged=1&action2=-1'
					)
				) . '">' . esc_html( count( $total ) ) . '</a>' : '0'
			);
		} // column_events

		/**
		 * Create the HTML output for the next event column
		 *
		 * @param   obj $item   The object array for the current item
		 *
		 * @return  str     The HTML output for the next event column
		 */
		public function column_next( $item ) {
			$next = tmem_get_clients_next_event( $item->ID );

			if ( ! empty( $next ) ) {
				echo '<a href="' . esc_url( get_edit_post_link( $next[0]->ID ) ) . '">' . esc_html( tmem_get_event_date( $next[0]->ID ) ) . '</a>';
			} else {
				echo esc_html__( 'N/A', 'mobile-events-manager' );
			}

		} // column_next

		/**
		 * Create the HTML output for the login column
		 *
		 * @param   obj $item   The object array for the current item
		 *
		 * @return  str     The HTML output for the login column
		 */
		public function column_login( $item ) {
			if ( '' != get_user_meta( $item->ID, 'last_login', true ) ) {
				echo esc_html( date( 'H:i d M Y', strtotime( get_user_meta( $item->ID, 'last_login', true ) ) ) );

			} else {
				echo esc_html__( 'Never', 'mobile-events-manager' );
			}
		} // column_login

		/**
		 * Generate the role view filters
		 *
		 * @param
		 *
		 * @return  $views      Array of $view => $link
		 */
		public function get_views() {
			global $wp_roles;

			$views   = array();
			$current = self::$display_role;

			// All roles link
			$class        = ( empty( $current ) || $current == 'all' ? ' class="current"' : '' );
			$all_url      = remove_query_arg( 'display_role' );
			$views['all'] = '<a href="' . $all_url . '" ' . $class . '>' . __( 'All', 'mobile-events-manager' ) .
				' <span class="count">(' . self::$total_clients . ')</span></a>';

			// Loop through all roles and generate the required views for each
			$roles = array( 'client', 'inactive_client' );
			foreach ( $roles as $key => $role ) {
				$count = count( tmem_get_clients( $role ) );

				if ( empty( $count ) ) {
					continue;
				}

				$class          = ( $current == $role ? ' class="current"' : '' );
				$role_url       = add_query_arg( 'display_role', $role );
				$views[ $role ] = '<a href="' . $role_url . '" ' . $class . '>' . translate_user_role( $wp_roles->roles[ $role ]['name'] ) .
					 ' <span class="count">(' . $count . ')</span></a>';
			}

			if ( ! empty( $_POST['s'] ) ) {
				$class           = ( $current == $role ? ' class="current"' : '' );
				$views['search'] = '<a href="#" ' . $class . '>' . __( 'Search Results', 'mobile-events-manager' ) .
					 ' <span class="count">(' . count( self::$clients ) . ')</span></a>';
			}

			return $views;
		} // get_views

		/**
		 * Add the bulk actions to the table header and footer and define the options
		 *
		 * @params
		 *
		 * @return  arr     $actions        The options for the bulk action dropdown
		 */
		public function get_bulk_actions() {
			$actions = array(
				'delete' => __( 'Delete Client', 'mobile-events-manager' ),
			);

			if ( ! isset( $_GET['display_role'] ) || $_GET['display_role'] == 'inactive_client' ) {
				$actions['active'] = 'Mark Active';
			}

			if ( ! isset( $_GET['display_role'] ) || $_GET['display_role'] == 'client' ) {
				$actions['inactive'] = 'Mark Inactive';
			}

			return $actions;
		} // get_bulk_actions

		/**
		 * Process bulk actions if requested
		 *
		 * @param
		 *
		 * @return
		 */
		public function process_bulk_actions() {
			$action = $this->current_action();

			if ( empty( $action ) ) {
				return;
			}

			$i = 0;

			if ( 'delete' === $action && ! empty( $_POST['client'] ) ) {
				foreach ( array_map( 'sanitize_text_field', wp_unslash( $_POST['client'] ) ) as $user_id ) {
					if ( TMEM_DEBUG == true ) {
						TMEM()->debug->log_it( 'Deleting client with ID ' . $user_id, true );
					}

					wp_delete_user( $user_id );
					$i++;
				}

				tmem_update_notice( 'updated', __( $i . ' Client(s) deleted.', 'mobile-events-manager' ), true );
			}
			if ( 'inactive' === $action || 'active' === $action ) {
				if ( empty( $_POST['client'] ) ) {
					return;
				}

				foreach ( array_map( 'sanitize_text_field', wp_unslash( $_POST['client'] ) ) as $user_id ) {
					if ( TMEM_DEBUG == true ) {
						TMEM()->debug->log_it( 'Setting client with ID ' . $user_id . ' to ' . ucfirst( $this->current_action() ), true );
					}

					$user = new WP_User( $user_id );

					$user->set_role( $action == 'inactive' ? 'inactive_client' : 'client' );
					$i++;
				}

				tmem_update_notice( 'updated', __( $i . ' Client(s) updated.', 'mobile-events-manager' ), true );
			}
		} // process_bulk_actions
	} // class TMEM_Client_Manager
endif;
	new TMEM_Client_Manager();
