<?php



/**
 * Contains misc functions.
 *
 * @package     TMEM
 * @subpackage  Functions
 * @since       1.3
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Set the correct date format for the jQuery date picker
 *
 * @since   1.3
 * @param
 * @return
 */
function tmem_format_datepicker_date() {
	$date_format = tmem_get_option( 'short_date_format', 'd/m/Y' );

	$search  = array( 'd', 'm', 'Y' );
	$replace = array( 'dd', 'mm', 'yy' );

	$date_format = str_replace( $search, $replace, $date_format );

	return apply_filters( 'tmem_format_datepicker_date', $date_format );
} // tmem_format_datepicker_date

/**
 * Add the TMEM MCE Shortcode button.
 *
 * @since   1.3
 * @param
 * @return
 */
function tmem_display_shortcode_button() {

	// Define the post types & screens within which the MCE button should be displayed
	$post_types = array( 'email_template', 'contract', 'page' );

	$screens = array(
		'tmem-event_page_tmem-comms',
		'tmem-event_page_tmem-settings',
	);

	// Add the TMEM TinyMCE buttons
	$current_screen = get_current_screen();

	if ( in_array( get_post_type(), $post_types ) || in_array( $current_screen->id, $screens ) ) {

		if ( 'true' == get_user_option( 'rich_editing' ) ) {
			add_filter( 'mce_external_plugins', 'tmem_register_mce_plugin' );
			add_filter( 'mce_buttons', 'tmem_register_mce_buttons' );
		}
	}

} // tmem_display_shortcode_button
add_action( 'admin_head', 'tmem_display_shortcode_button' );

/**
 * Get File Extension
 *
 * Returns the file extension of a filename.
 *
 * @since    1.5
 *
 * @param    unknown $str    File name
 * @return   mixed       File extension
 */
function tmem_get_file_extension( $str ) {
	$parts = explode( '.', $str );
	return end( $parts );
} // tmem_get_file_extension

/**
 * Given an object or array of objects, convert them to arrays
 *
 * @since   1.5
 * @param   object|array $object An object or an array of objects
 * @return  arr            An array or array of arrays, converted from the provided object(s)
 */
function tmem_object_to_array( $object = array() ) {

	if ( empty( $object ) || ( ! is_object( $object ) && ! is_array( $object ) ) ) {
		return $object;
	}

	if ( is_array( $object ) ) {
		$return = array();
		foreach ( $object as $item ) {
			if ( is_a( $object, 'TMEM_Event' ) ) {
				$return[] = $object->array_convert();
			} else {
				$return[] = tmem_object_to_array( $item );
			}
		}
	} else {
		if ( is_a( $object, 'TMEM_Event' ) ) {
			$return = $object->array_convert();
		} else {
			$return = get_object_vars( $object );

			// Now look at the items that came back and convert any nested objects to arrays
			foreach ( $return as $key => $value ) {
				$value          = ( is_array( $value ) || is_object( $value ) ) ? tmem_object_to_array( $value ) : $value;
				$return[ $key ] = $value;
			}
		}
	}

	return $return;

} // tmem_object_to_array

/**
 * Register the script that inserts ths TMEM Shortcodes into the content
 * when the TMEM Shortcode button is used
 *
 * @since   1.3
 * @param   arr $plugin_array   Array of registered MCE plugins
 * @return  arr     $plugin_array   Filtered array of registered MCE plugins
 */
function tmem_register_mce_plugin( $plugin_array ) {

	$plugin_array['tmem_shortcodes_btn'] = TMEM_PLUGIN_URL . '/assets/js/tmem-tinymce-shortcodes.js';

	return $plugin_array;

} // tmem_register_mce_plugin

/*
 * Register the TMEM Shortcode button within the TinyMCE interface
 *
 * @since	1.3
 * @params	arr		$buttons	Array of registered MCE buttons
 * @return	arr		$buttons	Filtered array of registered MCE buttons
 */
function tmem_register_mce_buttons( $buttons ) {

	array_push( $buttons, 'tmem_shortcodes_btn' );

	return $buttons;
} // tmem_register_mce_buttons

/**
 * Datepicker.
 *
 * @since   1.3
 * @param   arr $args   Datepicker field serttings.
 * @return  void
 */
function tmem_insert_datepicker( $args = array() ) {
	$defaults = array(
		'class'       => 'tmem_date',
		'altfield'    => '_tmem_event_date',
		'altformat'   => 'yy-mm-dd',
		'firstday'    => get_option( 'start_of_week' ),
		'changeyear'  => 'true',
		'changemonth' => 'true',
	);

	$args = wp_parse_args( $args, $defaults );

	if ( ! empty( $args['id'] ) ) {
		$field = '#' . $args['id'];
	} else {
		$field = '.' . $args['class'];
	}

	wp_enqueue_style( 'jquery-ui-css' );

	?>
	<script type="text/javascript">
	jQuery(document).ready( function($)	{
		$("<?php echo esc_html( $field ); ?>").datepicker({
			dateFormat  : "<?php echo esc_attr( tmem_format_datepicker_date() ); ?>",
			altField    : "#<?php echo esc_attr( $args['altfield'] ); ?>",
			altFormat   : "<?php echo esc_attr( $args['altformat'] ); ?>",
			firstDay    : "<?php echo esc_attr( $args['firstday'] ); ?>",
			changeYear  : "<?php echo esc_attr( $args['changeyear'] ); ?>",
			changeMonth : "<?php echo esc_attr( $args['changemonth'] ); ?>",
			minDate     : "<?php echo ( isset( $args['mindate'] ) ) ? esc_attr( $args['mindate'] ) : ''; ?>",
			maxDate     : "<?php echo ( isset( $args['maxdate'] ) ) ? esc_attr( $args['maxdate'] ) : ''; ?>"
		});
/** Fix to force use jQuery not Bootstrapper.
  * Copyright 2021 Dan Porter, Jack Mawhinney
*/
		$('<?php echo esc_html( $field ); ?>').on('changeDate', function() {
			var tmemdate_ = $(this).val();
			var tmemdate_ = tmemdate_.split('-').reverse().join('-');
			var tmemdate_ = tmemdate_.replace(/-/g,"/");
		$('#<?php echo esc_attr( $args['altfield'] ); ?>').val(tmemdate_);
		});
	});
	</script>
	<?php
} // tmem_insert_datepicker


/**
 * Month Num To Name
 *
 * Takes a month number and returns the name three letter name of it.
 *
 * @since   1.0
 *
 * @param   int  $n
 * @param   bool $full   True to output the full month name
 * @return  str     Short month name
 */
function tmem_month_num_to_name( $n, $full = false ) {
	$timestamp = mktime( 0, 0, 0, $n, 1, 2005 );

	$output = $full ? 'F' : 'M';

	return date_i18n( $output, $timestamp );
} // tmem_month_num_to_name

/**
 * Generate a random alphanumeric string.
 *
 * @since   1.5.6
 * @param   string|int $prefix A prefix for the string
 * @param   string|int $suffic A suffix for the string
 * @param   int        $length The length of the random string
 * @param   bool       $lower  True for lowercase, false for upper
 */
function tmem_generate_random_string( $prefix = '', $suffix = '', $length = 6, $lower = true ) {
	$range   = array_merge( range( 0, 9 ), range( 'a', 'z' ), range( 'A', 'Z' ) );
	$string  = '';
	$prefix .= ! empty( $prefix ) ? sanitize_text_field( $prefix ) : '';
	$suffix .= ! empty( $suffix ) ? sanitize_text_field( $suffix ) : '';

	for ( $x = 0; $x < 2; $x++ ) {
		for ( $i = 0; $i < $length; $i++ ) {
			$string .= $range[ mt_rand( 0, count( $range ) - 1 ) ];
		}

		$string .= '';
	}

	$string = $prefix . rtrim( $string, '-' ) . $suffix;
	$string = ! $lower ? strtoupper( $string ) : strtolower( $string );

	return $string;
} // tmem_generate_random_string

/**
 * Get PHP Arg Separator Output
 *
 * @since   1.3.8
 * @return  str     Arg separator output
 */
function tmem_get_php_arg_separator_output() {
	return ini_get( 'arg_separator.output' );
} // tmem_get_php_arg_separator_output

/**
 * Checks whether function is disabled.
 *
 * @since   1.4
 *
 * @param   str $function   Name of the function.
 * @return  bool    Whether or not function is disabled.
 */
function tmem_is_func_disabled( $function ) {
	$disabled = explode( ',', ini_get( 'disable_functions' ) );

	return in_array( $function, $disabled );
} // tmem_is_func_disabled

/**
 * Get the current page URL
 *
 * @since   1.3
 * @param
 * @return  str     $page_url   Current page URL
 */
function tmem_get_current_page_url() {
	$scheme = is_ssl() ? 'https' : 'http';
	$uri    = esc_url( site_url( sanitize_text_field( wp_unslash( $_SERVER['REQUEST_URI'] ) ), $scheme ) ); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotValidated

	if ( is_front_page() ) {
		$uri = home_url();
	}

	$uri = apply_filters( 'tmem_get_current_page_url', $uri );

	return $uri;
} // tmem_get_current_page_url

/**
 * Retrieve the visitors IP address.
 *
 * @since   1.3.8
 * @return  str
 */
function tmem_get_user_ip() {
	if ( ! empty( $_SERVER['HTTP_CLIENT_IP'] ) ) {
		$ip_address = sanitize_text_field( wp_unslash( $_SERVER['HTTP_CLIENT_IP'] ) );
	} elseif ( ! empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
		$ip_address = sanitize_text_field( wp_unslash( $_SERVER['HTTP_X_FORWARDED_FOR'] ) );
	} else {
		$ip_address = sanitize_text_field( wp_unslash( $_SERVER['REMOTE_ADDR'] ) ); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotValidated
	}

	return apply_filters( 'tmem_get_user_ip', $ip_address );
} // tmem_get_user_ip

/**
 * Display a Notice.
 *
 * Display a notice on the front end.
 *
 * @since   1.3
 * @param   int $m      The notice message key.
 * @return  str     The HTML string for the notice
 */
function tmem_display_notice( $m ) {
	$message = tmem_messages( $m );

	$notice  = '<div class="tmem-alert tmem-alert-' . $message['class'] . '">';
	$notice .= ! empty( $message['title'] ) ? '<span><strong>' . $message['title'] . '</strong></span><br />' : '';
	$notice .= $message['message'] . '</div>';

	return apply_filters( 'tmem_display_notice', $notice, $m );
} // tmem_display_notice

/**
 * Display notice on front end.
 *
 * Check for super global $_GET['tmem-message'] key and return message if set.
 *
 * @since   1.3
 * @param
 * @return  str     Out the relevant message to the browser.
 */
function tmem_print_notices() {
	if ( ! isset( $_GET, $_GET['tmem_message'] ) ) {
		return;
	}

	if ( isset( $_GET['event_id'] ) ) {

		$tmem_event = new TMEM_Event( absint( wp_unslash( $_GET['event_id'] ) ) );

		echo tmem_do_content_tags( tmem_display_notice( sanitize_text_field( wp_unslash( $_GET['tmem_message'] ) ) ), $tmem_event->ID, $tmem_event->client ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	} else {
		echo tmem_display_notice( sanitize_text_field( wp_unslash( $_GET['tmem_message'] ) ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	}
} // tmem_print_notices
add_action( 'tmem_print_notices', 'tmem_print_notices' );

/**
 * Messages.
 *
 * Messages that are used on the front end.
 *
 * @since   1.3
 * @param   str $key        Array key of notice to retrieve. All by default.
 * @return  arr     Array containing message text, title and class.
 */
function tmem_messages( $key ) {

	$messages = apply_filters(
		'tmem_messages',
		array(
			'login_profile'               => array(
				'class'   => 'info',
				'title'   => __( 'Login Required', 'mobile-events-manager' ),
				'message' => __( 'Please login to update your details.', 'mobile-events-manager' ),
			),
			'password_incorrect'          => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => __( 'Incorrect password.', 'mobile-events-manager' ),
			),
			'username_incorrect'          => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => __( 'Unknown username.', 'mobile-events-manager' ),
			),
			'missing_event'               => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => sprintf( __( 'We could not locate the details of your %s.', 'mobile-events-manager' ), tmem_get_label_singular( true ) ),
			),
			'enquiry_accepted'            => array(
				'class'   => 'success',
				'title'   => __( 'Thanks', 'mobile-events-manager' ),
				'message' => __( 'You have accepted our quote and details of your contract are now on their way to you via email.', 'mobile-events-manager' ),
			),
			'enquiry_accept_fail'         => array(
				'class'   => 'error',
				'title'   => __( 'Sorry', 'mobile-events-manager' ),
				'message' => __( 'We could not process your request.', 'mobile-events-manager' ),
			),
			'contract_signed'             => array(
				'class'   => 'success',
				'title'   => __( 'Done', 'mobile-events-manager' ),
				'message' => sprintf( __( 'You have successfully signed your %s contract. Confirmation will be sent to you via email in the next few minutes.', 'mobile-events-manager' ), tmem_get_label_singular( true ) ),
			),
			'contract_not_signed'         => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => sprintf( __( 'Unable to sign %s contract.', 'mobile-events-manager' ), tmem_get_label_singular( true ) ),
			),
			'contract_data_missing'       => array(
				'class'   => 'error',
				'title'   => __( 'Data missing', 'mobile-events-manager' ),
				'message' => __( 'Please ensure all fields have been completed, you have accepted the terms, confirmed your identity and re-entered your password.', 'mobile-events-manager' ),
			),
			'playlist_added'              => array(
				'class'   => 'success',
				'title'   => __( 'Done', 'mobile-events-manager' ),
				'message' => __( 'Playlist entry added.', 'mobile-events-manager' ),
			),
			'playlist_not_added'          => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => __( 'Unable to add playlist entry.', 'mobile-events-manager' ),
			),
			'playlist_data_missing'       => array(
				'class'   => 'error',
				'title'   => __( 'Data missing', 'mobile-events-manager' ),
				'message' => __( 'Please provide at least a song and an artist for this entry.', 'mobile-events-manager' ),
			),
			'playlist_removed'            => array(
				'class'   => 'success',
				'title'   => __( 'Done', 'mobile-events-manager' ),
				'message' => __( 'Playlist entry removed.', 'mobile-events-manager' ),
			),
			'playlist_not_removed'        => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => __( 'Unable to remove playlist entry.', 'mobile-events-manager' ),
			),
			'playlist_not_selected'       => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => __( 'No playlist entry selected.', 'mobile-events-manager' ),
			),
			'playlist_guest_added'        => array(
				'class'   => 'success',
				'title'   => __( 'Done', 'mobile-events-manager' ),
				'message' => __( 'Playlist suggestion submitted.', 'mobile-events-manager' ),
			),
			'playlist_guest_error'        => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => __( 'Unable to add playlist suggestion.', 'mobile-events-manager' ),
			),
			'playlist_guest_data_missing' => array(
				'class'   => 'error',
				'title'   => __( 'Data missing', 'mobile-events-manager' ),
				'message' => __( 'Please provide at least a song and an artist for this entry.', 'mobile-events-manager' ),
			),
			'available'                   => array(
				'class'   => 'tmem_available',
				'message' => tmem_get_option( 'availability_check_pass_text', __( 'The date you selected is available.', 'mobile-events-manager' ) ),
			),
			'not_available'               => array(
				'class'   => 'tmem_notavailable',
				'message' => tmem_get_option( 'availability_check_fail_text', __( "We're not available on the selected date.", 'mobile-events-manager' ) ),
			),
			'missing_date'                => array(
				'class'   => 'error',
				'title'   => __( 'Ooops', 'mobile-events-manager' ),
				'message' => __( 'You forgot to enter a date.', 'mobile-events-manager' ),
			),
			'missing_event'               => array(
				'class'   => 'error',
				'title'   => __( 'Sorry', 'mobile-events-manager' ),
				'message' => sprintf( __( 'We seem to be missing the %s details.', 'mobile-events-manager' ), tmem_get_label_singular( true ) ),
			),
			'password_error'              => array(
				'class'   => 'error',
				'title'   => __( 'Password Error', 'mobile-events-manager' ),
				'message' => __( 'An incorrect password was entered', 'mobile-events-manager' ),
			),
			'nonce_fail'                  => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => __( 'Security verification failed.', 'mobile-events-manager' ),
			),
			'payment_success'             => array(
				'class'   => 'success',
				'title'   => __( 'Thank you', 'mobile-events-manager' ),
				'message' => __( 'Your payment has completed successfully', 'mobile-events-manager' ),
			),
			'payment_failed'              => array(
				'class'   => 'error',
				'title'   => __( 'There was an error processing your payment', 'mobile-events-manager' ),
				'message' => __( 'To process your payment again, please follow the steps below', 'mobile-events-manager' ),
			),
			'agree_to_policy'             => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => __( 'You must acknowledge and accept our privacy policy', 'mobile-events-manager' ),
			),
			'agree_to_terms'              => array(
				'class'   => 'error',
				'title'   => __( 'Error', 'mobile-events-manager' ),
				'message' => __( 'You must agree to the terms and conditions', 'mobile-events-manager' ),
			),
		)
	);

	// Return a single message
	if ( isset( $key ) && array_key_exists( $key, $messages ) ) {
		return $messages[ $key ];
	} elseif ( isset( $key ) && ! array_key_exists( $key, $messages ) ) {
		return;
	}

	// Return all messages
	return $messages;
} // tmem_messages

/**
 * Validate the form honeypot to protect against bots.
 *
 * @since   1.4.7
 * @param   arr $data   Form post data
 * @return  void
 */
function tmem_do_honeypot_check( $data ) {
	if ( ! empty( $data['tmem_honeypot'] ) ) {
		wp_die( esc_html__( "Ha! I don't think so little honey bee. No bots allowed in this Honey Pot!", 'mobile-events-manager' ) );
	}

	return;
} // tmem_do_honeypot_check

/**
 * Check if the upgrade routine has been run for a specific action
 *
 * @since  2.3
 * @param  string $upgrade_action The upgrade action to check completion for
 * @return bool                   If the action has been added to the copmleted actions array
 */
function tmem_has_upgrade_completed( $upgrade_action = '' ) {

	if ( empty( $upgrade_action ) ) {
		return false;
	}

	$completed_upgrades = tmem_get_completed_upgrades();

	return in_array( $upgrade_action, $completed_upgrades );

} // tmem_has_upgrade_completed

/**
 * Retrieve the array of completed upgrade actions.
 *
 * @since   1.4
 * @return  arr     The array of completed upgrades.
 */
function tmem_get_completed_upgrades() {

	$completed_upgrades = get_option( 'tmem_completed_upgrades', array() );

	return $completed_upgrades;

} // tmem_get_completed_upgrades

/**
 * Wrapper for set_time_limit to see if it is enabled.
 *
 * @since 1.5.8
 * @param int $limit Time limit.
 */
function tmem_set_time_limit( $limit = 0 ) {
	if ( function_exists( 'set_time_limit' ) && false === strpos( ini_get( 'disable_functions' ), 'set_time_limit' ) && ! ini_get( 'safe_mode' ) ) { // phpcs:ignore PHPCompatibility.IniDirectives.RemovedIniDirectives.safe_modeDeprecatedRemoved
		@set_time_limit( $limit );
	}
}


/**
 * Class to check for premium addons
 *
 * @since 1.0.4
 */
$CheckTMEMPremium = new TMEM_Check_Premium();
class TMEM_Check_Premium {
	public function check_tmem_premium() {
			$addons = array(
				'tmem-stripe-payments.php',
				'mem-enquiry-forms.php',
			);

			$get_active_plugins = (array) get_option( 'active_plugins', array() );

			if ( is_multisite() ) {
				$get_active_plugins = array_merge( $get_active_plugins, array_keys( get_site_option( 'active_sitewide_plugins', array() ) ) );
			}

			$plugin_filenames = array();

			foreach ( $get_active_plugins as $plugin ) {

				if ( false !== strpos( $plugin, '/' ) ) {
					// plugin name (dir/plugin-filename.php)
					list( , $plugin_filename ) = explode( '/', $plugin );

				} else {
					// no dir, just plugin file name
					$plugin_filename = esc_html( $plugin );
				}

				$plugin_filenames[] = $plugin_filename;
			}

			return ! empty( array_intersect( $plugin_filenames, $addons ) );
	}
}
