<?php
/**
 * This plugin utilizes Open Source code. Details of these open source projects along with their licenses can be found below.
 * We acknowledge and are grateful to these developers for their contributions to open source.
 *
 * Project: mobile-dj-manager https://github.com/deckbooks/mobile-dj-manager
 * License: (GNU General Public License v2.0) https://github.com/deckbooks/mobile-dj-manager/blob/master/license.txt
 *
 * This template is used to display the items which can be paid for on the payment form.
 *
 * @version         1.0
 * @author          Mike Howard, Jack Mawhinney, Dan Porter
 * @content_tag     {client_*}
 * @content_tag     {event_*}
 * @shortcodes      Supported
 *
 * Do not customise this file!
 * If you wish to make changes, copy this file to your theme directory /theme/tmem-templates/payments/payments-items.php
 */
require_once TMEM_PLUGIN_DIR . '/includes/admin/settings/register-settings.php';
require_once TMEM_PLUGIN_DIR . '/includes/admin/events/playlist-page.php';

global $tmem_event;
$deposit_disabled = '';
if ( 'Paid' == $tmem_event->get_deposit_status() ) {
	$deposit_disabled = ' disabled = "true"';
}

$balance_disabled = '';
if ( 'Paid' == $tmem_event->get_balance_status() ) {
	$balance_disabled = ' disabled = "true"';
}
$other_amount_style = ' style="display: none;"';
if ( ! empty( $balance_disabled ) && ! empty( $deposit_disabled ) ) {
	$other_amount_style = '';
}

if ( empty( $deposit_disabled ) ) {
	$selected = 'deposit';
} elseif ( empty( $balance_disabled ) ) {
	$selected = 'balance';
} else {
	$selected = 'part_payment';
}

?>
<fieldset id="tmem-payment-value">
	<legend><?php esc_html_e( 'Select Payment Amount', 'mobile-events-manager' ); ?></legend>
	<p class="tmem-payment-amount">
		<input type="radio" name="tmem_payment_amount" data-amount="<?php echo $tmem_event->get_remaining_deposit();?>" id="tmem-payment-deposit" value="deposit"<?php echo $deposit_disabled; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?><?php checked( $selected, 'deposit' ); ?> /> <?php echo esc_html( tmem_get_deposit_label() ); ?> &ndash; <?php echo tmem_currency_filter( tmem_format_amount( $tmem_event->get_remaining_deposit() ) ); ?><br />

		<input type="radio" name="tmem_payment_amount" data-amount="<?php echo $tmem_event->get_balance();?>" id="tmem-payment-balance" value="balance"<?php echo $balance_disabled; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?><?php checked( $selected, 'balance' ); ?> /> <?php echo esc_html( tmem_get_balance_label() ); ?> &ndash; <?php echo tmem_currency_filter( tmem_format_amount( $tmem_event->get_balance() ) ); ?><br />

		<input type="radio" name="tmem_payment_amount" id="tmem-payment-part" min="1" max="1000000" step="any" data-amount="50.00" value="part_payment"<?php checked( $selected, 'part_payment' ); ?> /> <?php echo esc_html( tmem_get_other_amount_label() ); ?> <span id="tmem-payment-custom"<?php echo $other_amount_style; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>><?php echo esc_html( tmem_currency_symbol() ); ?><input type="number" class="tmem_other_amount_input tmem-input" name="part_payment" id="part-payment" value="50.00"/></span>
   <span class="tmem-description"><?php printf( esc_html__( 'To pay a custom amount, select %s and enter the value into the text field.', 'mobile-events-manager' ), esc_html( tmem_get_other_amount_label() ) ); ?></span><br/>
 </p>
</fieldset>
<?php if ( tmem_get_option( 'enable_bacs') === "1" ){?>
  <fieldset id="tmem-payment-value">
    <legend><?php printf( esc_html__( 'Pay by BACS', 'mobile-events-manager' ) ); ?></legend>

    <?php if ( tmem_get_option( 'bacs_info' ) ){?>
      <small><?php echo esc_html( tmem_get_option( 'bacs_info') ) ?></small>
    <?php }?> <br />

    <span style="font-weight: bold"><?php printf( esc_html__( 'Account Name: ' ) ); ?></span><?php printf( esc_html( tmem_get_option( 'bank_detail_name', '' ) ) ); ?><br/>
    <span style="font-weight: bold"><?php printf( esc_html__( 'Sort Code: ' ) ); ?></span><?php printf( esc_html( tmem_get_option( 'bank_detail_sortcode', '' ) ) ); ?><br/>
    <span style="font-weight: bold"><?php printf( esc_html__( 'Account Number: ' ) ); ?></span><?php printf( esc_html( tmem_get_option( 'bank_detail_accnumber', '' ) ) ); ?><br/>
    <span style="font-weight: bold"><?php printf( esc_html__( 'Reference: ' ) ) ?></span><?php printf( esc_html( tmem_get_event_contract_id( $tmem_event->ID ) ) )?></span> 


  </span>
</fieldset>
<?php } ?>

<script>
	jQuery(document).ready(function($){
    $('input#part-payment').on('input',function(){
     var part_val = $(this).val();
     $('#tmem-payment-part').attr('data-amount', part_val);
   });
  });
</script>